/**
 * @file
 * eTracker admin behaviors.
 */

(function ($) {

  'use strict';

  /**
   * Provide the summary information for the tracking settings vertical tabs.
   */
  Drupal.behaviors.trackingSettingsSummary = {
    attach: function () {
      // Make sure this behavior is processed only if drupalSetSummary is defined.
      if (typeof jQuery.fn.drupalSetSummary === 'undefined') {
        return;
      }

      $('#edit-pages').drupalSetSummary(function (context) {
        var $radio = $('input[name="etracker_track_path_mode"]:checked', context);
        if ($radio.val() === 'all_pages') {
          if (!$('textarea[name="etracker_track_paths"]', context).val()) {
            return Drupal.t('Not restricted');
          }
          else {
            return Drupal.t('All pages with exceptions');
          }
        }
        else {
          return Drupal.t('Restricted to certain pages');
        }
      });

      $('#edit-roles').drupalSetSummary(function (context) {
        var vals = [];
        $('input[type="checkbox"]:checked', context).each(function () {
          vals.push($.trim($(this).next('label').text()));
        });
        if (!vals.length) {
          return Drupal.t('Not restricted');
        }
        else if ($('input[name="etracker_track_roles_mode"]:checked', context).val() === 'all_roles') {
          return Drupal.t('Excepted: @roles', {'@roles': vals.join(', ')});
        }
        else {
          return vals.join(', ');
        }
      });

      $('#edit-users').drupalSetSummary(function (context) {
        var $radio = $('input[name="etracker_track_user"]:checked', context);
        if ($radio.val() === 'no_customization') {
          return Drupal.t('Not customizable');
        }
        else if ($radio.val() === 'tracking_on') {
          return Drupal.t('On by default with opt out');
        }
        else {
          return Drupal.t('Off by default with opt in');
        }
      });

      $('#edit-breadcrumb').drupalSetSummary(function (context) {
        var vals = [];
        if ($('input#edit-etracker-mode-breadcrumb-as-area-breadcrumb-on', context).is(':checked')) {
          vals.push(Drupal.t('Show area hierarchy'));
        }
        if ($('input#edit-etracker-mode-breadcrumb-as-area-breadcrumb-exclude-home', context).is(':checked')) {
          vals.push(Drupal.t('Hide home page'));
        }
        if (!vals.length) {
          return Drupal.t('Not tracked');
        }
        return Drupal.t('@items enabled', {'@items': vals.join(', ')});
      });

      $('#edit-linktracking').drupalSetSummary(function (context) {
        var vals = [];
        if ($('input#edit-track-mailto', context).is(':checked')) {
          vals.push(Drupal.t('Mailto links'));
        }
        if ($('input#edit-track-external', context).is(':checked')) {
          vals.push(Drupal.t('Outbound links'));
        }
        if ($('input#edit-track-download', context).is(':checked')) {
          vals.push(Drupal.t('Downloads'));
        }
        if (!vals.length) {
          return Drupal.t('Not tracked');
        }
        return Drupal.t('@items enabled', {'@items': vals.join(', ')});
      });

      $('#edit-messagetracking').drupalSetSummary(function (context) {
        var vals = [];
        $('input[type="checkbox"]:checked', context).each(function () {
          vals.push($.trim($(this).next('label').text()));
        });
        if (!vals.length) {
          return Drupal.t('Not tracked');
        }
        return Drupal.t('@items enabled', {'@items': vals.join(', ')});
      });

      $('#edit-privacy').drupalSetSummary(function (context) {
        var vals = [];
        if ($('input#edit-data-respect-dnt', context).is(':checked')) {
          vals.push(Drupal.t('Universal web tracking opt-out enabled'));
        }
        if ($('input#edit-data-block-cookies', context).is(':checked')) {
          vals.push(Drupal.t('Cookies disabled'));
        }
        if (!vals.length) {
          return Drupal.t('No privacy');
        }
        return Drupal.t('@items', {'@items': vals.join(', ')});
      });
    }
  };

})(jQuery);
