/**
 * @file
 * Defines Javascript behaviors for the etracker module.
 */
(function (drupalSettings) {
  'use strict';

  // Register event listener only if any setting is enabled.
  if(
    drupalSettings.etracker.track_mailto
    || drupalSettings.etracker.track_download
    || drupalSettings.etracker.track_external
  ) {
    // Attach mousedown, keyup, touchstart events to document only
    ['mousedown', 'keyup', 'touchstart'].forEach(function (e) {
      document.querySelector('body').addEventListener(e, function (event) {
        if(event.target.tagName === 'A' || event.target.tagName === 'AREA') {
          // Mailto link clicked.
          if (drupalSettings.etracker.track_mailto && event.target.href.startsWith('mailto:')) {
            _etracker.sendEvent(new et_ClickEvent(('E-Mail:%20' + event.target.href.substring(7), 'E-Mail')));
          }
          // Download link clicked.
          else if (drupalSettings.etracker.track_download && (new RegExp("\\.(" + drupalSettings.etracker.track_download_extensions.split(' ').join('|') + ")(\\?|$)").test(event.target.href))) {
            _etracker.sendEvent(new et_UserDefinedEvent(event.target.href, 'Download'));
          }
          // External link clicked.
          else if (drupalSettings.etracker.track_external && event.target.host !== window.location.host) {
            _etracker.sendEvent(new et_UserDefinedEvent('External link:%20' + event.target.href, ''));
          }
        }
      });
    });
  }

  // Trigger events for each message being displayed.
  if (drupalSettings.etracker.messages.length > 0) {
    for (var i in drupalSettings.etracker.messages) {
      _etracker.sendEvent(new et_UserDefinedEvent(drupalSettings.etracker.messages[i].text, 'Message', drupalSettings.etracker.messages[i].type, ''));
    }
  }

})(drupalSettings);
